package com.mortals.xhx.module.matter.service.impl;
import com.mortals.framework.common.Rest;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.model.Result;
import com.mortals.xhx.common.pdu.RespData;
import com.mortals.xhx.common.pdu.matter.MatterDatumPdu;
import com.mortals.xhx.common.pdu.matter.MatterPdu;
import com.mortals.xhx.common.pdu.site.SiteMatterPdu;
import com.mortals.xhx.common.pdu.site.SiteThemeMatterPdu;
import com.mortals.xhx.common.utils.BeanUtil;
import com.mortals.xhx.feign.matter.IMatterDatumFeign;
import com.mortals.xhx.feign.matter.IMatterFeign;
import com.mortals.xhx.feign.site.ISiteMatterFeign;
import com.mortals.xhx.feign.site.ISiteThemeMatterFeign;
import com.mortals.xhx.module.matter.model.MatterApplyQuery;
import com.mortals.xhx.module.matter.model.vo.MatterApplyGroupVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.matter.dao.MatterApplyDao;
import com.mortals.xhx.module.matter.model.MatterApplyEntity;
import com.mortals.xhx.module.matter.service.MatterApplyService;
import org.springframework.util.ObjectUtils;

import java.util.*;
import java.util.stream.Collectors;

/**
* MatterApplyService
* 申报事项 service实现
*
* @author zxfei
* @date 2023-04-07
*/
@Service("matterApplyService")
public class MatterApplyServiceImpl extends AbstractCRUDServiceImpl<MatterApplyDao, MatterApplyEntity, Long> implements MatterApplyService {

    @Autowired
    private ISiteMatterFeign siteMatterFeign;
    @Autowired
    private IMatterFeign matterFeign;
    @Autowired
    private ISiteThemeMatterFeign siteThemeMatterFeign;
    @Autowired
    private IMatterDatumFeign matterDatumFeign;

    @Override
    public void addReportCount(Long id) {
        Map<String,Object> data = new HashMap<>();
        data.put("reportCountIncrement",1);
        Map<String,Object> condition = new HashMap<>();
        condition.put("id",id);
        dao.update(data,condition);
    }

    @Override
    public void addDatumCount(Long id,Integer increment) {
        Map<String,Object> data = new HashMap<>();
        data.put("datumCountIncrement",increment);
        Map<String,Object> condition = new HashMap<>();
        condition.put("id",id);
        dao.update(data,condition);
    }

    @Override
    public Rest<String> addToAssist(String siteMatterIds, Context context) {
        List<Long> matterIdList = Arrays.asList(siteMatterIds.split(",")).stream().map(Long::parseLong).collect(Collectors.toList());
        SiteMatterPdu matterQuery = new SiteMatterPdu();
        matterQuery.setIdList(matterIdList);
        matterQuery.setSize(-1);
        Rest<RespData<List<SiteMatterPdu>>> result = siteMatterFeign.list(matterQuery);
        if(result.getCode()==1){
            List<SiteMatterPdu> matterEntities = result.getData().getData();
            int success = 0;
            int fail = 0;
            List<MatterApplyEntity> singelMatterEntities = new ArrayList<>();

            for (SiteMatterPdu matterEntity : matterEntities) {
                MatterApplyEntity singelMatterEntity = updateOrSave(matterEntity, context);
                if (!ObjectUtils.isEmpty(singelMatterEntity)) {
                    singelMatterEntities.add(singelMatterEntity);
                    success++;
                } else {
                    fail++;
                }
            }
            if (!ObjectUtils.isEmpty(singelMatterEntities)) {
                this.save(singelMatterEntities, context);
            }
            String msg = "当前加入事项已存在！";
            if (matterIdList.size() == 1) {
                if (success > 0) {
                    msg = "加入事项成功！";
                }
            } else if (matterIdList.size() > 1) {
                if (success > 0 && fail == 0) {
                    msg = String.format("加入事项成功%d条!", success);
                } else if (success > 0 && fail > 0) {
                    msg = String.format("加入事项成功%d条，重复加入事项%d条！", success, fail);
                } else if (success == 0 && fail > 0) {
                    msg = String.format("重复加入事项%d条！", fail);
                }
            }
            return Rest.ok(msg);
        }else {
            return Rest.fail("添加失败");
        }
    }

    private MatterApplyEntity updateOrSave(SiteMatterPdu item, Context context) {
        MatterApplyEntity singleMatterEntity = this.selectOne(new MatterApplyQuery().siteMatterId(item.getId()));

        if (ObjectUtils.isEmpty(singleMatterEntity)) {
            MatterApplyEntity singleEntity = BeanUtil.covert(item,MatterApplyEntity.class);
            singleEntity.setDatumCount(0);
            singleEntity.setReportCount(0);
            singleEntity.setCreateTime(new Date());
            if(context!=null&&context.getUser()!=null) {
                singleEntity.setCreateUserId(context.getUser().getId());
            }
            singleEntity.setSiteMatterId(item.getId());
//            singleEntity.setGovUrl(item.getUrl());
            Rest<MatterPdu> matterPduRest = matterFeign.info(item.getMatterId());
            if(matterPduRest.getCode()==1 && matterPduRest.getData()!=null){
                singleEntity.setGovUrl(matterPduRest.getData().getUrl());
                SiteThemeMatterPdu query = new SiteThemeMatterPdu();
                query.setMatterId(item.getMatterId());
                query.setSiteId(item.getSiteId());
                query.setSize(-1);
                Rest<RespData<List<SiteThemeMatterPdu>>> siteThemeMatterList = siteThemeMatterFeign.list(query);
                if(siteThemeMatterList.getCode()==1 && siteThemeMatterList.getData()!=null){
                    Map<String,String> themeMap = new HashMap<>();
                    for(SiteThemeMatterPdu themeMatterPdu:siteThemeMatterList.getData().getData()){
                        themeMap.put(themeMatterPdu.getThemeCode(),themeMatterPdu.getThemeName());
                    }
                    String themeCode = "";
                    String themeName = "";
                    for (Map.Entry<String, String> entry : themeMap.entrySet()) {
                        themeCode += entry.getKey() + ",";
                        themeName += entry.getValue() + ",";
                    }
                    singleEntity.setThemeCode(themeCode.endsWith(",")?themeCode.substring(0,themeCode.indexOf(",")):themeCode);
                    singleEntity.setThemeName(themeName.endsWith(",")?themeName.substring(0,themeName.indexOf(",")):themeName);
                }
                MatterDatumPdu datumPdu = new MatterDatumPdu();
                datumPdu.setMatterId(item.getMatterId());
                datumPdu.setSize(-1);
                Rest<RespData<List<MatterDatumPdu>>> datumlist = matterDatumFeign.list(datumPdu);
                if(datumlist.getCode()==1 && datumlist.getData()!=null){
                    singleEntity.setDatumCount(datumlist.getData().getData().size());
                }
            }
            return singleEntity;
        }else {
            return null;
        }
    }

    @Override
    public Result<MatterApplyGroupVo> findDeptGroup(MatterApplyEntity params, PageInfo pageInfo, Context context) throws AppException {
        Result<MatterApplyGroupVo> result = this.dao.getDeptGroupList(params, pageInfo);
        return result;
    }

    @Override
    public Result<MatterApplyGroupVo> findThemeGroup(MatterApplyEntity params, PageInfo pageInfo, Context context) throws AppException {
        Result<MatterApplyGroupVo> result = this.dao.getThemeGroupList(params, pageInfo);
        return result;
    }
}