package com.mortals.xhx.module.matter.service.impl;
import com.mortals.framework.common.Rest;
import com.mortals.framework.model.PageInfo;
import com.mortals.xhx.base.system.upload.service.UploadService;
import com.mortals.xhx.common.utils.BeanUtil;
import com.mortals.xhx.module.matter.model.*;
import com.mortals.xhx.module.matter.service.DatumLibraryService;
import com.mortals.xhx.module.matter.service.MatterDatumFileService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.matter.dao.MatterDatumDao;
import com.mortals.xhx.module.matter.service.MatterDatumService;
import org.springframework.util.CollectionUtils;
import org.springframework.util.ObjectUtils;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
* MatterDatumService
* 事项申请材料业务 service实现
*
* @author zxfei
* @date 2023-04-07
*/
@Service("matterDatumService")
public class MatterDatumServiceImpl extends AbstractCRUDServiceImpl<MatterDatumDao, MatterDatumEntity, Long> implements MatterDatumService {

    @Autowired
    private MatterDatumFileService matterDatumFileService;
    @Autowired
    private UploadService uploadService;
    @Autowired
    private DatumLibraryService datumLibraryService;

    @Override
    protected void findAfter(MatterDatumEntity params, Context context, List<MatterDatumEntity> list) throws AppException {

        list.stream().peek(item->{
            List<MatterDatumFileEntity> matterDatumFileEntities = matterDatumFileService.find(new MatterDatumFileQuery().datumId(item.getId()));
            item.setMatterDatumFileList(matterDatumFileEntities);
        }).count();
        super.findAfter(params, context, list);
    }

    @Override
    protected void findAfter(MatterDatumEntity params, PageInfo pageInfo, Context context, List<MatterDatumEntity> list) throws AppException {

        list.stream().peek(item->{
            List<MatterDatumFileEntity> matterDatumFileEntities = matterDatumFileService.find(new MatterDatumFileQuery().datumId(item.getId()));
            item.setMatterDatumFileList(matterDatumFileEntities);
        }).count();
        super.findAfter(params, context, list);
    }

    @Override
    protected void saveBefore(MatterDatumEntity entity, Context context) throws AppException {
        super.saveBefore(entity,context);
        entity.setFillSum(0);
        entity.setSuggest(0);
        if(entity.getNeedType()==null){
            entity.setNeedType(0);
        }
        if(entity.getDatumType()==null){
            entity.setDatumType(0);
        }
        if(entity.getNeedOriginal()==null){
            entity.setNeedOriginal(0);
        }
    }
    @Override
    protected void saveAfter(MatterDatumEntity entity, Context context) throws AppException {
        if (!ObjectUtils.isEmpty(entity.getMatterDatumFileList())) {
            entity.getMatterDatumFileList().stream().peek(item -> {
                item.setDatumId(entity.getId());
                item.setUselType(entity.getUselType());
                item.setMatterId(entity.getMatterId());
                item.setMatterCode(entity.getMatterCode());
            }).count();
            matterDatumFileService.save(entity.getMatterDatumFileList());
        }
        if(entity.getIsAddLibrary()!=null && entity.getIsAddLibrary()==1){
            addToLibrary(entity.getId()+"", context);
        }
        super.saveAfter(entity, context);
    }

    @Override
    protected void updateAfter(MatterDatumEntity entity, Context context) throws AppException {
        if (!ObjectUtils.isEmpty(entity.getMatterDatumFileList())) {
            //先删除后新增
            Long[] fileIds = matterDatumFileService.find(new MatterDatumFileQuery().datumId(entity.getId())).stream()
                    .map(item -> {
                        uploadService.deleteFile(item.getTemplatePath());
                        uploadService.deleteFile(item.getSamplePath());
                        uploadService.deleteFile(item.getPreviewUrl());
                        return item.getId();
                    }).toArray(Long[]::new);
            matterDatumFileService.remove(fileIds, context);
            entity.getMatterDatumFileList().stream().peek(item -> {
                item.setDatumId(entity.getId());
            }).count();
            matterDatumFileService.save(entity.getMatterDatumFileList());
        }
        super.updateAfter(entity, context);
    }


    @Override
    public Rest<String> addToLibrary(String datumIds, Context context) {

        List<Long> datumIdList = Arrays.asList(datumIds.split(",")).stream().map(Long::parseLong).collect(Collectors.toList());
        MatterDatumQuery datumQuery = new MatterDatumQuery();
        datumQuery.setIdList(datumIdList);
        List<MatterDatumEntity> entities = this.find(datumQuery);
        int success = 0;
        int fail = 0;
        List<DatumLibraryEntity> addEntities = new ArrayList<>();

        for (MatterDatumEntity datum : entities) {
            DatumLibraryEntity datumLibrary = updateOrSave(datum, context);
            //SiteMatterEntity siteMatterEntity = updateOrSave(matterEntity, siteId, context);
            if (!ObjectUtils.isEmpty(datumLibrary)) {
                addEntities.add(datumLibrary);
                success++;
            } else {
                fail++;
            }
        }
        if (!ObjectUtils.isEmpty(addEntities)) {
            datumLibraryService.save(addEntities, context);
        }
        String msg = "当前加入材料已存在！";
        if(CollectionUtils.isEmpty(entities)){
            msg = "没有可以添加的数据！";
        }
        if (datumIdList.size() == 1) {
            if (success > 0) {
                msg = "加入材料成功！";
            }
        } else if (datumIdList.size() > 1) {
            if (success > 0 && fail == 0) {
                msg = String.format("加入材料成功%d条!", success);
            } else if (success > 0 && fail > 0) {
                msg = String.format("加入材料成功%d条，重复加入材料%d条！", success, fail);
            } else if (success == 0 && fail > 0) {
                msg = String.format("重复加入材料%d条！", fail);
            }
        }
        return Rest.ok(msg);
    }

    private DatumLibraryEntity updateOrSave(MatterDatumEntity item, Context context) {
        DatumLibraryEntity siteDatumLibraryEntity = datumLibraryService.selectOne(new DatumLibraryQuery().siteId(item.getSiteId()).datumId(item.getId()));
        if (ObjectUtils.isEmpty(siteDatumLibraryEntity)) {

            DatumLibraryEntity datumLibraryEntity = BeanUtil.covert(item,DatumLibraryEntity.class);
            datumLibraryEntity.setDatumId(item.getId());
            datumLibraryEntity.setCreateTime(new Date());
            if(context!=null&&context.getUser()!=null) {
                datumLibraryEntity.setCreateUserId(context.getUser().getId());
            }
            return datumLibraryEntity;
        }
        return null;
    }
}