package com.mortals.xhx.module.sst.service.impl;
import com.mortals.framework.util.DataUtil;
import com.mortals.xhx.common.utils.StringUtils;
import com.mortals.xhx.module.apps.model.AppsInfoEntity;
import com.mortals.xhx.module.apps.service.AppsInfoService;
import com.mortals.xhx.module.sst.model.SstAppsDeskEntity;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.sst.dao.SstAppsDeskDao;
import com.mortals.xhx.module.sst.model.SstAppsDeskEntity;
import com.mortals.xhx.module.sst.service.SstAppsDeskService;

import java.util.*;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
* SstAppsDeskService
* 桌面终端应用编排 service实现
*
* @author zxfei
* @date 2023-04-09
*/
@Service("sstAppsDeskService")
public class SstAppsDeskServiceImpl extends AbstractCRUDServiceImpl<SstAppsDeskDao, SstAppsDeskEntity, Long> implements SstAppsDeskService {
    @Autowired
    private AppsInfoService appsInfoService;

    @Override
    public Map<String, Object> getAppsBySiteId(Long siteId) throws AppException {
        if(siteId == null){
            throw new AppException("站点id不能为空");
        }
        AppsInfoEntity appsInfoQuery = new AppsInfoEntity();
        appsInfoQuery.setSiteId(siteId);
        List<AppsInfoEntity> allApps = appsInfoService.find(appsInfoQuery);
        SstAppsDeskEntity query = new SstAppsDeskEntity();
        Map<String,String> orderCols = new HashMap<>();
        orderCols.put("basicSort","DESC");
        query.setOrderCols(orderCols);
        query.setSiteId(siteId);
        List<SstAppsDeskEntity> appsEntities = this.find(query);
        Map<String, Object> siteApp = new HashMap<>();
        siteApp.put("allApps", allApps);
        if(CollectionUtils.isNotEmpty(appsEntities)){
            List<SstAppsDeskEntity> showApps = new ArrayList<>();
            List<SstAppsDeskEntity> hotApps = new ArrayList<>();
            for(SstAppsDeskEntity SstAppsDeskEntity:appsEntities){
                if(SstAppsDeskEntity.getShowBasic()==1){
                    showApps.add(SstAppsDeskEntity);
                }
                if(SstAppsDeskEntity.getShowHot()==1){
                    hotApps.add(SstAppsDeskEntity);
                }
            }
            siteApp.put("showApps", showApps);
            siteApp.put("hotApps", hotApps);
        }else {
            siteApp.put("showApps", Collections.emptyList());
            siteApp.put("hotApps", Collections.emptyList());
        }
        return siteApp;
    }

    @Override
    public void settingSave(Long siteId, String showAppIds, String hotAppIds,Context context) throws AppException {
        Map<Long,SstAppsDeskEntity> sstAppIds = new HashMap<>();

        if(StringUtils.isNotEmpty(showAppIds)){
            String appIds[] = showAppIds.split(",");
            int sort = 99;
            for(String id:appIds){
                Long appId = DataUtil.converStr2Long(id,0l);
                AppsInfoEntity appsInfoEntity = appsInfoService.get(appId);
                if(appsInfoEntity!=null) {
                    SstAppsDeskEntity SstAppsDeskEntity = new SstAppsDeskEntity();
                    SstAppsDeskEntity.setSiteId(siteId);
                    SstAppsDeskEntity.setAppId(appId);
                    SstAppsDeskEntity.setName(appsInfoEntity.getName());
                    SstAppsDeskEntity.setDescribe(appsInfoEntity.getDescribe());
                    SstAppsDeskEntity.setUrl(appsInfoEntity.getUrl());
                    SstAppsDeskEntity.setShowBasic(1);
                    SstAppsDeskEntity.setBasicSort(sort);
                    SstAppsDeskEntity.setShowHot(0);
                    SstAppsDeskEntity.setHotSort(0);
                    if(context!=null){
                        SstAppsDeskEntity.setCreateUserId(context.getUser().getId());
                        SstAppsDeskEntity.setCreateTime(new Date());
                    }
                    sstAppIds.put(appId, SstAppsDeskEntity);
                    sort--;
                }
            }
        }
        if(StringUtils.isNotEmpty(hotAppIds)){
            String appIds[] = hotAppIds.split(",");
            int sort = 99;
            for(String id:appIds){
                Long appId = DataUtil.converStr2Long(id,0l);
                if(sstAppIds.containsKey(appId)){
                    sstAppIds.get(appId).setShowHot(1);
                    sstAppIds.get(appId).setHotSort(sort);
                    sort--;
                }else {
                    AppsInfoEntity appsInfoEntity = appsInfoService.get(appId);
                    if (appsInfoEntity != null) {
                        SstAppsDeskEntity SstAppsDeskEntity = new SstAppsDeskEntity();
                        SstAppsDeskEntity.setSiteId(siteId);
                        SstAppsDeskEntity.setAppId(appId);
                        SstAppsDeskEntity.setName(appsInfoEntity.getName());
                        SstAppsDeskEntity.setDescribe(appsInfoEntity.getDescribe());
                        SstAppsDeskEntity.setUrl(appsInfoEntity.getUrl());
                        SstAppsDeskEntity.setShowBasic(0);
                        SstAppsDeskEntity.setBasicSort(0);
                        SstAppsDeskEntity.setShowHot(1);
                        SstAppsDeskEntity.setHotSort(sort);
                        if (context != null) {
                            SstAppsDeskEntity.setCreateUserId(context.getUser().getId());
                            SstAppsDeskEntity.setCreateTime(new Date());
                        }
                        sstAppIds.put(appId, SstAppsDeskEntity);
                        sort--;
                    }
                }
            }
        }
        Map<String,Object> condition = new HashMap<>();
        condition.put("siteId",siteId);
        this.dao.delete(condition);
        if(sstAppIds.size()>0){
            List<SstAppsDeskEntity> list = sstAppIds.values().stream().collect(Collectors.toList());
            this.dao.insertBatch(list);
        }
    }

    @Override
    public Map<String, Object> getAppListBySite(Long siteId,String host) {
        SstAppsDeskEntity query = new SstAppsDeskEntity();
        Map<String,String> orderCols = new HashMap<>();
        orderCols.put("basicSort","DESC");
        query.setOrderCols(orderCols);
        query.setSiteId(siteId);
        List<SstAppsDeskEntity> appsEntities = this.find(query);

        AppsInfoEntity appsInfoQuery = new AppsInfoEntity();
        appsInfoQuery.setSiteId(siteId);
        List<AppsInfoEntity> allApps = appsInfoService.find(appsInfoQuery);
        for(AppsInfoEntity appsInfoEntity:allApps){
            if(com.mortals.framework.util.StringUtils.isNotEmpty(host)) {
                appsInfoEntity.setCustUrl(host + "/" + appsInfoEntity.getCustUrl());
            }
        }
        Map<Long,AppsInfoEntity> appInfoMap = allApps.stream().collect(Collectors.toMap(AppsInfoEntity::getId, Function.identity()));
        Map<String, Object> siteApp = new HashMap<>();
        siteApp.put("allApps", allApps);
        if(CollectionUtils.isNotEmpty(appsEntities)){
            List<AppsInfoEntity> showApps = new ArrayList<>();
            List<AppsInfoEntity> hotApps = new ArrayList<>();
            for(SstAppsDeskEntity SstAppsDeskEntity:appsEntities){
                if(SstAppsDeskEntity.getShowBasic()==1){
                    showApps.add(appInfoMap.get(SstAppsDeskEntity.getAppId()));
                }
                if(SstAppsDeskEntity.getShowHot()==1){
                    hotApps.add(appInfoMap.get(SstAppsDeskEntity.getAppId()));
                }
            }
            siteApp.put("showApps", showApps);
            siteApp.put("hotApps", hotApps);
        }else {
            siteApp.put("showApps", Collections.emptyList());
            siteApp.put("hotApps", Collections.emptyList());
        }
        return siteApp;
    }

    @Override
    public void forbidden(Long appId, Long userId) {
        Map<String,Object> condition = new HashMap<>();
        condition.put("appId",appId);
        this.dao.delete(condition);
    }
}