package com.mortals.xhx.module.sst.web;
import cn.hutool.core.lang.Validator;
import cn.hutool.core.net.url.UrlBuilder;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSON;
import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.Rest;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.service.IUser;
import com.mortals.framework.util.DataUtil;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.common.code.YesNoEnum;
import com.mortals.xhx.common.key.ParamKey;
import com.mortals.xhx.feign.base.IApiBaseManagerFeign;
import com.mortals.xhx.feign.base.pdu.SitePdu;
import com.mortals.xhx.feign.rsp.ApiResp;
import com.mortals.xhx.feign.site.ISiteFeign;
import com.mortals.xhx.module.sst.model.SstAppsEntity;
import com.mortals.xhx.module.sst.service.SstAppsDeskService;
import com.mortals.xhx.module.sst.service.SstAppsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;
import com.mortals.framework.model.Context;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.module.sst.model.SstBasicEntity;
import com.mortals.xhx.module.sst.service.SstBasicService;
import org.apache.commons.lang3.ArrayUtils;
import com.mortals.framework.util.StringUtils;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import static com.mortals.framework.ap.SysConstains.*;
/**
*
* 基础配置
*
* @author zxfei
* @date 2022-12-21
*/
@RestController
@RequestMapping("basic")
public class SstBasicController extends BaseCRUDJsonBodyMappingController<SstBasicService,SstBasicEntity,Long> {

    @Autowired
    private IApiBaseManagerFeign iApiBaseManagerFeign;

    @Autowired
    private ParamService paramService;

    @Autowired
    private SstAppsService sstAppsService;

    @Autowired
    private SstAppsDeskService sstAppsDeskService;

    @Autowired
    private ISiteFeign iSiteFeign;

    public SstBasicController(){
        super.setModuleDesc( "基础配置");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model, "elderEnable", paramService.getParamBySecondOrganize("SstBasic","elderEnable"));
        super.init(model, context);
    }

    @PostMapping({"setting/info"})
    public Rest<Object> settingInfo(@RequestBody SstBasicEntity query) {
        IUser user = this.getCurUser();
        if(user==null){
            throw new AppException("用户未登录");
        }
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        String busiDesc = "查询自助终端基础设置信息" ;
        int code=1;
        try {
            SstBasicEntity sstBasic = this.service.getBasicBySiteId(query.getSiteId());
            Map<String, Object> sstApps = sstAppsService.getAppsBySiteId(query.getSiteId());
            Map<String, Object> sstAppsDesk = sstAppsDeskService.getAppsBySiteId(query.getSiteId());
            model.put("basicInfo", sstBasic);
            model.put("showApps", sstApps.get("showApps"));
            model.put("hotApps", sstApps.get("hotApps"));
            model.put("allApps", sstApps.get("allApps"));
            model.put("showAppsDesk", sstAppsDesk.get("showApps"));
            model.put("hotAppsDesk", sstAppsDesk.get("hotApps"));
            model.put("allAppsDesk", sstAppsDesk.get("allApps"));
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    @PostMapping({"setting/save"})
    public Rest<Object> settingSave(@RequestBody SstBasicEntity basicEntity) {
        IUser user = this.getCurUser();
        if(user==null){
            throw new AppException("用户未登录");
        }
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        String busiDesc = "保存基础设置" ;
        int code=1;
        try {
            this.service.settingSave(basicEntity,this.getContext());
            this.sstAppsService.settingSave(basicEntity.getSiteId(),basicEntity.getShowAppIds(),basicEntity.getHotAppIds(),this.getContext());
            this.sstAppsDeskService.settingSave(basicEntity.getSiteId(),basicEntity.getDeskShowAppIds(),basicEntity.getDeskHotAppIds(),this.getContext());
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    @PostMapping({"site/siteTree"})
    public Rest<Object> list(@RequestHeader("Authorization") String authorization) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        String busiDesc = "查询用户站点列表";

        int code = 1;
        try {
            String resp = iSiteFeign.siteTree(authorization);
            ApiResp<JSONObject> apiResp = JSON.parseObject(resp, ApiResp.class);
            if (apiResp.getCode() != YesNoEnum.YES.getValue()) {
                throw new AppException("获取用户站点列表树数据失败：" + apiResp.getMsg());
            }
            if (apiResp.getData().get("siteTree") != null) {
                model.put("data", apiResp.getData().get("siteTree"));
            } else {
                model.put("data", Collections.emptyList());
            }
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    @PostMapping({"site/list"})
    public Rest<Object> list() {
        IUser user = this.getCurUser();
        if (user == null) {
            throw new AppException("用户未登录");
        }
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        String busiDesc = "查询用户站点列表";

        int code = 1;
        try {

            if (StringUtils.isNotEmpty(user.getSiteIds())) {
                SitePdu sitePdu = new SitePdu();
                List<String> siteIds = Arrays.asList(user.getSiteIds().split(","));
                List<Long> idList = new ArrayList<>();
                siteIds.forEach(s -> {
                    idList.add(DataUtil.converStr2Long(s, 0));
                });
                sitePdu.setIdList(idList);
                String resp = iApiBaseManagerFeign.getSitesByQuery(sitePdu);
                ApiResp<JSONObject> apiResp = JSON.parseObject(resp, ApiResp.class);
                if (apiResp.getCode() != YesNoEnum.YES.getValue()) {
                    throw new AppException("获取用户站点列表树数据失败：" + apiResp.getMsg());
                }
                if (apiResp.getData().get("data") != null) {
                    model.put("data", apiResp.getData().get("data"));
                } else {
                    model.put("data", Collections.emptyList());
                }
            } else {
                model.put("data", Collections.emptyList());
            }
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    @PostMapping({"site/apps"})
    @UnAuth
    public Rest<Object> showApps(@RequestBody SstBasicEntity query) {
//        IUser user = this.getCurUser();
//        if(user==null){
//            throw new AppException("用户未登录");
//        }
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        String busiDesc = "查询自助终端应用展示数据" ;
        int code=1;
        try {
            String host = "";
            String serverName = request.getHeader("server-name");
            Integer serverPort = DataUtil.converStr2Int(request.getHeader("server-port"),0);
            if (!ObjectUtils.isEmpty(serverName) && Validator.isIpv4(serverName)) {
                host = UrlBuilder.ofHttp(serverName).setPort(serverPort > 0 ? serverPort : 11078).build();
                host = StrUtil.sub(host, 0, host.length() - 1);
            }else {
                host="";
            }
            log.info("server-name:"+serverName+",server-port:"+serverPort);
            Map<String, Object> sstApps = sstAppsService.getAppListBySite(query.getSiteId(),host);
            model.put("showApps", sstApps.get("showApps"));
            model.put("hotApps", sstApps.get("hotApps"));
            model.put("allApps", sstApps.get("allApps"));
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    @PostMapping({"site/desk/apps"})
    @UnAuth
    public Rest<Object> showDeskApps(@RequestBody SstBasicEntity query) {
//        IUser user = this.getCurUser();
//        if(user==null){
//            throw new AppException("用户未登录");
//        }
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        String busiDesc = "查询自助终端应用展示数据" ;
        int code=1;
        try {
            String host = "";
            String serverName = request.getHeader("server-name");
            Integer serverPort = DataUtil.converStr2Int(request.getHeader("server-port"),0);
            if (!ObjectUtils.isEmpty(serverName) && Validator.isIpv4(serverName)) {
                host = UrlBuilder.ofHttp(serverName).setPort(serverPort > 0 ? serverPort : 11078).build();
                host = StrUtil.sub(host, 0, host.length() - 1);
            }else {
                host="";
            }
            log.info("server-name:"+serverName+",server-port:"+serverPort);
            Map<String, Object> sstAppsDesk = sstAppsDeskService.getAppListBySite(query.getSiteId(),host);
            model.put("showApps", sstAppsDesk.get("showApps"));
            model.put("hotApps", sstAppsDesk.get("hotApps"));
            model.put("allApps", sstAppsDesk.get("allApps"));
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

}